summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorSandro S. Andrade <sandroandrade@kde.org>2013-01-26 13:41:58 -0300
committerSandro S. Andrade <sandroandrade@kde.org>2013-01-26 17:43:04 +0100
commit605261a6d352afa100d8461c460c04eedd7f3cbe (patch)
treefdf5e7e7ec95080e81e4c6193e37523707ec8f97
parent07fdeae31a1aa5900a6da2a50769b811ec027fc7 (diff)
Split QtWrappedObjects in QtWrappedObjects/QtWrappedObjectsWidgets
That allows for unit tests run without DISPLAY and dbus dependency Change-Id: Idcb2bc299b99d181d6d769b6f67534151c026308 Reviewed-by: Sandro S. Andrade <sandroandrade@kde.org>
-rw-r--r--examples/uml/qtumleditor/mainwindow.cpp7
-rw-r--r--examples/uml/qtumleditor/mainwindow.h12
-rw-r--r--examples/uml/qtumleditor/qtumleditor.pro2
-rw-r--r--examples/uml/qtumleditor/qwrappedobjectpropertyeditor.cpp2
-rw-r--r--examples/uml/qtumleditor/qwrappedobjectpropertyeditor.h4
-rw-r--r--examples/uml/qtumleditor/qwrappedobjectview.cpp4
-rw-r--r--modules/qtwrappedobjectswidgets.pri17
-rw-r--r--src/src.pro2
-rw-r--r--src/wrappedobjects/wrappedobjects.pro6
-rw-r--r--src/wrappedobjectswidgets/doc/qtwrappedobjectswidgets.qdocconf41
-rw-r--r--src/wrappedobjectswidgets/doc/snippets/code/doc_src_qtwrappedobjects.cpp3
-rw-r--r--src/wrappedobjectswidgets/doc/snippets/code/doc_src_qtwrappedobjects.pro3
-rw-r--r--src/wrappedobjectswidgets/doc/src/qtwrappedobjectswidgets.qdoc66
-rw-r--r--src/wrappedobjectswidgets/qtwrappedobjectswidgetsglobal.h86
-rw-r--r--src/wrappedobjectswidgets/qwrappedobjectmodel.cpp (renamed from src/wrappedobjects/qwrappedobjectmodel.cpp)6
-rw-r--r--src/wrappedobjectswidgets/qwrappedobjectmodel.h (renamed from src/wrappedobjects/qwrappedobjectmodel.h)19
-rw-r--r--src/wrappedobjectswidgets/qwrappedobjectpropertymodel.cpp (renamed from src/wrappedobjects/qwrappedobjectpropertymodel.cpp)8
-rw-r--r--src/wrappedobjectswidgets/qwrappedobjectpropertymodel.h (renamed from src/wrappedobjects/qwrappedobjectpropertymodel.h)22
-rw-r--r--src/wrappedobjectswidgets/wrappedobjectswidgets.pro23
-rw-r--r--sync.profile4
-rw-r--r--tests/auto/qtmofcontainment/qtmofcontainment.pro2
-rw-r--r--tests/auto/qtumlcontainment/qtumlcontainment.pro2
22 files changed, 296 insertions, 45 deletions
diff --git a/examples/uml/qtumleditor/mainwindow.cpp b/examples/uml/qtumleditor/mainwindow.cpp
index 7af035f6..beb37a48 100644
--- a/examples/uml/qtumleditor/mainwindow.cpp
+++ b/examples/uml/qtumleditor/mainwindow.cpp
@@ -11,14 +11,13 @@
#include <QtWrappedObjects/QWrappedObject>
#include <QtWrappedObjects/QMetaModelPlugin>
-#include <QtWrappedObjects/QWrappedObjectModel>
-#include <QtWrappedObjects/QWrappedObjectPropertyModel>
+#include <QtWrappedObjectsWidgets/QWrappedObjectModel>
+#include <QtWrappedObjectsWidgets/QWrappedObjectPropertyModel>
#include <QtMof/QXmiWriter>
#include <QtMof/QXmiReader>
-using QtWrappedObjects::QMetaModelPlugin;
-using QtWrappedObjects::QWrappedObjectPropertyModel;
+using QtWrappedObjectsWidgets::QWrappedObjectPropertyModel;
MainWindow::MainWindow(QWidget *parent) :
QMainWindow(parent),
diff --git a/examples/uml/qtumleditor/mainwindow.h b/examples/uml/qtumleditor/mainwindow.h
index 2e4eeff8..ce4d29f0 100644
--- a/examples/uml/qtumleditor/mainwindow.h
+++ b/examples/uml/qtumleditor/mainwindow.h
@@ -8,11 +8,6 @@
class QDialog;
-namespace QtWrappedObjects
-{
- class QMetaModelPlugin;
-}
-
namespace Ui {
class MainWindow;
class AboutPlugins;
@@ -20,11 +15,16 @@ namespace Ui {
namespace QtWrappedObjects {
class QWrappedObject;
+ class QMetaModelPlugin;
+}
+
+namespace QtWrappedObjectsWidgets {
class QWrappedObjectModel;
}
+
using QtWrappedObjects::QWrappedObject;
-using QtWrappedObjects::QWrappedObjectModel;
using QtWrappedObjects::QMetaModelPlugin;
+using QtWrappedObjectsWidgets::QWrappedObjectModel;
class MainWindow : public QMainWindow
{
diff --git a/examples/uml/qtumleditor/qtumleditor.pro b/examples/uml/qtumleditor/qtumleditor.pro
index 2f2080c2..4ffb3c21 100644
--- a/examples/uml/qtumleditor/qtumleditor.pro
+++ b/examples/uml/qtumleditor/qtumleditor.pro
@@ -4,7 +4,7 @@
#
#-------------------------------------------------
-QT = core gui mof
+QT = wrappedobjects wrappedobjectswidgets mof
greaterThan(QT_MAJOR_VERSION, 4): QT += widgets
diff --git a/examples/uml/qtumleditor/qwrappedobjectpropertyeditor.cpp b/examples/uml/qtumleditor/qwrappedobjectpropertyeditor.cpp
index bef6550a..3b8ea6c2 100644
--- a/examples/uml/qtumleditor/qwrappedobjectpropertyeditor.cpp
+++ b/examples/uml/qtumleditor/qwrappedobjectpropertyeditor.cpp
@@ -5,7 +5,7 @@
#include <QtWidgets/QVBoxLayout>
#include <QtWrappedObjects/QWrappedObject>
-#include <QtWrappedObjects/QWrappedObjectPropertyModel>
+#include <QtWrappedObjectsWidgets/QWrappedObjectPropertyModel>
#include "filterwidget.h"
#include "propertyeditoritemdelegate.h"
diff --git a/examples/uml/qtumleditor/qwrappedobjectpropertyeditor.h b/examples/uml/qtumleditor/qwrappedobjectpropertyeditor.h
index aa5ffa4d..d020519a 100644
--- a/examples/uml/qtumleditor/qwrappedobjectpropertyeditor.h
+++ b/examples/uml/qtumleditor/qwrappedobjectpropertyeditor.h
@@ -7,13 +7,13 @@ class FilterWidget;
class QLabel;
class QTreeView;
-namespace QtWrappedObjects {
+namespace QtWrappedObjectsWidgets {
class QWrappedObjectPropertyModel;
}
class WrappedObjectPropertyFilterModel;
-using QtWrappedObjects::QWrappedObjectPropertyModel;
+using QtWrappedObjectsWidgets::QWrappedObjectPropertyModel;
class QWrappedObjectPropertyEditor : public QWidget
{
diff --git a/examples/uml/qtumleditor/qwrappedobjectview.cpp b/examples/uml/qtumleditor/qwrappedobjectview.cpp
index 19778163..e821e9b2 100644
--- a/examples/uml/qtumleditor/qwrappedobjectview.cpp
+++ b/examples/uml/qtumleditor/qwrappedobjectview.cpp
@@ -10,10 +10,10 @@
#include <QtWrappedObjects/QWrappedObject>
#include <QtWrappedObjects/QMetaWrappedObject>
-#include <QtWrappedObjects/QWrappedObjectModel>
+#include <QtWrappedObjectsWidgets/QWrappedObjectModel>
using QtWrappedObjects::QMetaWrappedObject;
-using QtWrappedObjects::QWrappedObjectModel;
+using QtWrappedObjectsWidgets::QWrappedObjectModel;
QWrappedObjectView::QWrappedObjectView(QWidget *parent) :
QWidget(parent),
diff --git a/modules/qtwrappedobjectswidgets.pri b/modules/qtwrappedobjectswidgets.pri
new file mode 100644
index 00000000..a6b5c22d
--- /dev/null
+++ b/modules/qtwrappedobjectswidgets.pri
@@ -0,0 +1,17 @@
+QT.wrappedobjectswidgets.VERSION = 5.0.0
+QT.wrappedobjectswidgets.MAJOR_VERSION = 5
+QT.wrappedobjectswidgets.MINOR_VERSION = 0
+QT.wrappedobjectswidgets.PATCH_VERSION = 0
+
+QT.wrappedobjectswidgets.name = QtWrappedObjectsWidgets
+QT.wrappedobjectswidgets.bins = $$QT_MODULE_BIN_BASE
+QT.wrappedobjectswidgets.includes = $$QT_MODULE_INCLUDE_BASE $$QT_MODULE_INCLUDE_BASE/$$QT.wrappedobjectswidgets.name
+QT.wrappedobjectswidgets.private_includes = $$QT_MODULE_INCLUDE_BASE/$$QT.wrappedobjectswidgets.name/$$QT.wrappedobjectswidgets.VERSION
+QT.wrappedobjectswidgets.sources = $$QT_MODULE_BASE/src/wrappedobjectswidgets
+QT.wrappedobjectswidgets.libs = $$QT_MODULE_LIB_BASE
+QT.wrappedobjectswidgets.plugins = $$QT_MODULE_PLUGIN_BASE
+QT.wrappedobjectswidgets.imports = $$QT_MODULE_IMPORT_BASE
+QT.wrappedobjectswidgets.depends = core
+
+QT.wrappedobjectswidgets.DEFINES = QT_WRAPPEDOBJECTSWIDGETS_LIB
+QT_CONFIG += wrappedobjectswidgets
diff --git a/src/src.pro b/src/src.pro
index dd2d5154..6e23238e 100644
--- a/src/src.pro
+++ b/src/src.pro
@@ -1,4 +1,4 @@
TEMPLATE = subdirs
CONFIG += ordered
-SUBDIRS = wrappedobjects mof uml plugins
+SUBDIRS = wrappedobjects wrappedobjectswidgets mof uml plugins
diff --git a/src/wrappedobjects/wrappedobjects.pro b/src/wrappedobjects/wrappedobjects.pro
index 67a102b5..326613fb 100644
--- a/src/wrappedobjects/wrappedobjects.pro
+++ b/src/wrappedobjects/wrappedobjects.pro
@@ -1,7 +1,7 @@
load(qt_build_config)
TARGET = QtWrappedObjects
-QT = core-private gui
+QT = core-private
QMAKE_DOCS = $$PWD/doc/qtwrappedobjects.qdocconf
@@ -13,8 +13,6 @@ PUBLIC_HEADERS += \
qmetawrappedobject.h \
qwrappedobjectpointer.h \
qtwrappedobjectsnamespace.h \
- qwrappedobjectmodel.h \
- qwrappedobjectpropertymodel.h \
qmetamodelplugin.h
PRIVATE_HEADERS += \
@@ -25,8 +23,6 @@ SOURCES += \
qwrappedobject.cpp \
qmetawrappedobject.cpp \
qtwrappedobjectsnamespace.cpp \
- qwrappedobjectmodel.cpp \
- qwrappedobjectpropertymodel.cpp \
qmetamodelplugin.cpp
HEADERS += $$PUBLIC_HEADERS $$PRIVATE_HEADERS
diff --git a/src/wrappedobjectswidgets/doc/qtwrappedobjectswidgets.qdocconf b/src/wrappedobjectswidgets/doc/qtwrappedobjectswidgets.qdocconf
new file mode 100644
index 00000000..58638975
--- /dev/null
+++ b/src/wrappedobjectswidgets/doc/qtwrappedobjectswidgets.qdocconf
@@ -0,0 +1,41 @@
+include($QT_INSTALL_DOCS/global/qt-module-defaults.qdocconf)
+
+project = QtWrappedObjectsWidgets
+description = Qt WrappedObjectsWidgets Reference Documentation
+url = http://qt-project.org/doc/qtwrappedobjectswidgets
+version = 5.0.0
+
+examplesinstallpath = wrappedobjectswidgets
+
+qhp.projects = QtWrappedObjectsWidgets
+
+qhp.QtWrappedObjectsWidgets.file = qtwrappedobjectswidgets.qhp
+qhp.QtWrappedObjectsWidgets.namespace = org.qt-project.qtwrappedobjectswidgets.500
+qhp.QtWrappedObjectsWidgets.virtualFolder = qtwrappedobjectswidgets
+qhp.QtWrappedObjectsWidgets.indexTitle = Qt WrappedObjectsWidgets
+qhp.QtWrappedObjectsWidgets.indexRoot =
+
+qhp.QtWrappedObjectsWidgets.filterAttributes = qtwrappedobjectswidgets 5.0.0 qtrefdoc
+qhp.QtWrappedObjectsWidgets.customFilters.Qt.name = QtWrappedObjectsWidgets 5.0.0
+qhp.QtWrappedObjectsWidgets.customFilters.Qt.filterAttributes = qtwrappedobjectswidgets 5.0.0
+
+qhp.QtWrappedObjectsWidgets.subprojects = classes
+qhp.QtWrappedObjectsWidgets.subprojects.classes.title = C++ Classes
+qhp.QtWrappedObjectsWidgets.subprojects.classes.indexTitle = Qt WrappedObjectsWidgets C++ Classes
+qhp.QtWrappedObjectsWidgets.subprojects.classes.selectors = class fake:headerfile
+qhp.QtWrappedObjectsWidgets.subprojects.classes.sortPages = true
+tagfile = ../../../doc/qtwrappedobjectswidgets/qtwrappedobjectswidgets.tags
+
+depends += qtcore wrappedobjects qtdoc
+
+headerdirs += ..
+
+sourcedirs += .. \
+ ../../../examples/wrappedobjectswidgets/doc/src
+
+exampledirs += ../../../examples/wrappedobjectswidgets \
+ ../ \
+ snippets
+
+imagedirs += images \
+ ../../../examples/wrappedobjectswidgets/doc/images
diff --git a/src/wrappedobjectswidgets/doc/snippets/code/doc_src_qtwrappedobjects.cpp b/src/wrappedobjectswidgets/doc/snippets/code/doc_src_qtwrappedobjects.cpp
new file mode 100644
index 00000000..879a4979
--- /dev/null
+++ b/src/wrappedobjectswidgets/doc/snippets/code/doc_src_qtwrappedobjects.cpp
@@ -0,0 +1,3 @@
+//! [0]
+#include <QtWrappedObjectsWidgets>
+//! [0]
diff --git a/src/wrappedobjectswidgets/doc/snippets/code/doc_src_qtwrappedobjects.pro b/src/wrappedobjectswidgets/doc/snippets/code/doc_src_qtwrappedobjects.pro
new file mode 100644
index 00000000..dda264e2
--- /dev/null
+++ b/src/wrappedobjectswidgets/doc/snippets/code/doc_src_qtwrappedobjects.pro
@@ -0,0 +1,3 @@
+#! [0]
+QT += wrappedobjectswidgets
+#! [0]
diff --git a/src/wrappedobjectswidgets/doc/src/qtwrappedobjectswidgets.qdoc b/src/wrappedobjectswidgets/doc/src/qtwrappedobjectswidgets.qdoc
new file mode 100644
index 00000000..cf0ada9b
--- /dev/null
+++ b/src/wrappedobjectswidgets/doc/src/qtwrappedobjectswidgets.qdoc
@@ -0,0 +1,66 @@
+/****************************************************************************
+**
+** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
+** Contact: http://www.qt-project.org/legal
+**
+** This file is part of the documentation of the Qt Toolkit.
+**
+** $QT_BEGIN_LICENSE:FDL$
+** Commercial License Usage
+** Licensees holding valid commercial Qt licenses may use this file in
+** accordance with the commercial license agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Digia. For licensing terms and
+** conditions see http://qt.digia.com/licensing. For further information
+** use the contact form at http://qt.digia.com/contact-us.
+**
+** GNU Free Documentation License Usage
+** Alternatively, this file may be used under the terms of the GNU Free
+** Documentation License version 1.3 as published by the Free Software
+** Foundation and appearing in the file included in the packaging of
+** this file. Please review the following information to ensure
+** the GNU Free Documentation License version 1.3 requirements
+** will be met: http://www.gnu.org/copyleft/fdl.html.
+** $QT_END_LICENSE$
+**
+****************************************************************************/
+/*!
+ \page qtwrappedobjectswidgets-index.html
+ \title Qt WrappedObjectsWidgets
+ \brief Provide model and widget classes for use with QtWrappedObjects module.
+
+ Qt WrappedObjectsWidgets is an add-on module which provides model and widget classes for use with QtWrappedObjects module.
+
+ \section1 Getting Started
+ To enable Qt WrappedObjectsWidgets in a project, add this directive into the C++ files:
+ \code
+ #include <QtWrappedObjectsWidgets>
+ \endcode
+ To link against the Qt WrappedObjectsWidgets module, add this line to the project file:
+ \code
+ QT += wrappedobjectswidgets
+ \endcode
+
+ \section1 Reference
+ These are links to the API reference materials.
+ \list
+ \li \l{Qt WrappedObjectsWidgets Module C++ Classes}{C++ classes}
+ \endlist
+*/
+
+/*!
+ \module QtWrappedObjectsWidgets
+ \title Qt WrappedObjectsWidgets Module C++ Classes
+ \ingroup modules
+ \brief Provide model and widget classes for use with QtWrappedObjects module.
+
+ To include the definitions of the module's classes, use the
+ following directive:
+
+ \snippet code/doc_src_qtwrappedobjectswidgets.cpp 0
+
+ To link against the module, add this line to your \l qmake \c
+ .pro file:
+
+ \snippet code/doc_src_qtwrappedobjectswidgets.pro 0
+*/
diff --git a/src/wrappedobjectswidgets/qtwrappedobjectswidgetsglobal.h b/src/wrappedobjectswidgets/qtwrappedobjectswidgetsglobal.h
new file mode 100644
index 00000000..d5ec7b2a
--- /dev/null
+++ b/src/wrappedobjectswidgets/qtwrappedobjectswidgetsglobal.h
@@ -0,0 +1,86 @@
+/****************************************************************************
+**
+** Copyright (C) 2012 Sandro S. Andrade <sandroandrade@kde.org>
+** Contact: http://www.qt-project.org/
+**
+** This file is part of the QtWrappedObjectsWidgets module of the Qt Toolkit.
+**
+** $QT_BEGIN_LICENSE:LGPL$
+** GNU Lesser General Public License Usage
+** This file may be used under the terms of the GNU Lesser General Public
+** License version 2.1 as published by the Free Software Foundation and
+** appearing in the file LICENSE.LGPL included in the packaging of this
+** file. Please review the following information to ensure the GNU Lesser
+** General Public License version 2.1 requirements will be met:
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+**
+** In addition, as a special exception, Nokia gives you certain additional
+** rights. These rights are described in the Nokia Qt LGPL Exception
+** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
+**
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU General
+** Public License version 3.0 as published by the Free Software Foundation
+** and appearing in the file LICENSE.GPL included in the packaging of this
+** file. Please review the following information to ensure the GNU General
+** Public License version 3.0 requirements will be met:
+** http://www.gnu.org/copyleft/gpl.html.
+**
+** Other Usage
+** Alternatively, this file may be used in accordance with the terms and
+** conditions contained in a signed written agreement between you and Nokia.
+**
+**
+**
+**
+**
+**
+** $QT_END_LICENSE$
+**
+****************************************************************************/
+#ifndef QTWRAPPEDOBJECTSWIDGETSGLOBAL_H
+#define QTWRAPPEDOBJECTSWIDGETSGLOBAL_H
+
+#include <QtCore/qglobal.h>
+
+QT_BEGIN_HEADER
+
+#ifndef QT_STATIC
+# if defined(QT_BUILD_WRAPPEDOBJECTSWIDGETS_LIB)
+# define Q_WRAPPEDOBJECTSWIDGETS_EXPORT Q_DECL_EXPORT
+# else
+# define Q_WRAPPEDOBJECTSWIDGETS_EXPORT Q_DECL_IMPORT
+# endif
+#else
+# define Q_WRAPPEDOBJECTSWIDGETS_EXPORT
+#endif
+
+// QtWrappedObjectsWidgets macros
+
+#if defined(Q_MOC_RUN)
+
+#define QT_NAMESPACE_QTWRAPPEDOBJECTSWIDGETS
+#define QT_BEGIN_NAMESPACE_QTWRAPPEDOBJECTSWIDGETS
+#define QT_END_NAMESPACE_QTWRAPPEDOBJECTSWIDGETS
+#define QT_USE_NAMESPACE_QTWRAPPEDOBJECTSWIDGETS
+#define QT_PREPEND_NAMESPACE_QTWRAPPEDOBJECTSWIDGETS(name) ::name
+
+#else
+
+#if defined(QT_NAMESPACE)
+# define QT_NAMESPACE_QTWRAPPEDOBJECTSWIDGETS QT_NAMESPACE::QtWrappedObjectsWidgets
+#else
+# define QT_NAMESPACE_QTWRAPPEDOBJECTSWIDGETS QtWrappedObjectsWidgets
+#endif
+
+#define QT_BEGIN_NAMESPACE_QTWRAPPEDOBJECTSWIDGETS QT_BEGIN_NAMESPACE namespace QtWrappedObjectsWidgets {
+#define QT_END_NAMESPACE_QTWRAPPEDOBJECTSWIDGETS QT_END_NAMESPACE }
+#define QT_USE_NAMESPACE_QTWRAPPEDOBJECTSWIDGETS using namespace ::QT_NAMESPACE_QTWRAPPEDOBJECTSWIDGETS;
+#define QT_PREPEND_NAMESPACE_QTWRAPPEDOBJECTSWIDGETS(name) ::QT_NAMESPACE_QTWRAPPEDOBJECTSWIDGETS::name
+
+#endif /* defined(Q_MOC_RUN) */
+
+QT_END_HEADER
+
+#endif // QTWRAPPEDOBJECTSWIDGETSGLOBAL_H
+
diff --git a/src/wrappedobjectswidgets/wrappedobjectswidgets.pro b/src/wrappedobjectswidgets/wrappedobjectswidgets.pro
new file mode 100644
index 00000000..e28a0798
--- /dev/null
+++ b/src/wrappedobjectswidgets/wrappedobjectswidgets.pro
@@ -0,0 +1,23 @@
+load(qt_build_config)
+
+TARGET = QtWrappedObjectsWidgets
+QT = wrappedobjects gui
+
+QMAKE_DOCS = $$PWD/doc/qtwrappedobjectswidgets.qdocconf
+
+load(qt_module)
+
+PUBLIC_HEADERS += \
+ qtwrappedobjectswidgetsglobal.h \
+ qwrappedobjectmodel.h \
+ qwrappedobjectpropertymodel.h
+
+#PRIVATE_HEADERS += \
+# qwrappedobject_p.h \
+# qmetawrappedobject_p.h
+
+SOURCES += \
+ qwrappedobjectmodel.cpp \
+ qwrappedobjectpropertymodel.cpp
+
+HEADERS += $$PUBLIC_HEADERS #$$PRIVATE_HEADERS
diff --git a/sync.profile b/sync.profile
index 291b4ab5..c91a852e 100644
--- a/sync.profile
+++ b/sync.profile
@@ -1,5 +1,6 @@
%modules = ( # path to module name map
"QtWrappedObjects" => "$basedir/src/wrappedobjects",
+ "QtWrappedObjectsWidgets" => "$basedir/src/wrappedobjectswidgets",
"QtMof" => "$basedir/src/mof",
"QtUml" => "$basedir/src/uml",
);
@@ -10,6 +11,8 @@
%classnames = (
"qtwrappedobjectsversion.h" => "QtWrappedObjectsVersion",
"qtwrappedobjectsglobal.h" => "QtWrappedObjectsGlobal",
+ "qtwrappedobjectswidgetsversion.h" => "QtWrappedObjectsWidgetsVersion",
+ "qtwrappedobjectswidgetsglobal.h" => "QtWrappedObjectsWidgetsGlobal",
"qtmofversion.h" => "QtMofVersion",
"qtmofglobal.h" => "QtMofGlobal",
"qtumlversion.h" => "QtUmlVersion",
@@ -21,6 +24,7 @@
%modulepris = (
"QtWrappedObjects" => "$basedir/modules/qtwrappedobjects.pri",
+ "QtWrappedObjectsWidgets" => "$basedir/modules/qtwrappedobjectswidgets.pri",
"QtMof" => "$basedir/modules/qtmof.pri",
"QtUml" => "$basedir/modules/qtuml.pri",
);
diff --git a/tests/auto/qtmofcontainment/qtmofcontainment.pro b/tests/auto/qtmofcontainment/qtmofcontainment.pro
index 25ec89f7..a329d73a 100644
--- a/tests/auto/qtmofcontainment/qtmofcontainment.pro
+++ b/tests/auto/qtmofcontainment/qtmofcontainment.pro
@@ -1,7 +1,7 @@
CONFIG += testcase c++11
TARGET = tst_qtmofcontainment
-QT += mof testlib
+QT = mof testlib
SOURCES += \
tst_qtmofcontainment.cpp \
diff --git a/tests/auto/qtumlcontainment/qtumlcontainment.pro b/tests/auto/qtumlcontainment/qtumlcontainment.pro
index 49bcad23..3c84209e 100644
--- a/tests/auto/qtumlcontainment/qtumlcontainment.pro
+++ b/tests/auto/qtumlcontainment/qtumlcontainment.pro
@@ -1,7 +1,7 @@
CONFIG += testcase c++11
TARGET = tst_qtumlcontainment
-QT += uml testlib
+QT = uml testlib
SOURCES += \
tst_qtumlcontainment.cpp \
diff --git a/src/wrappedobjects/qwrappedobjectmodel.cpp b/src/wrappedobjectswidgets/qwrappedobjectmodel.cpp
index 93e90bb0..938ef2ec 100644
--- a/src/wrappedobjects/qwrappedobjectmodel.cpp
+++ b/src/wrappedobjectswidgets/qwrappedobjectmodel.cpp
@@ -3,7 +3,7 @@
** Copyright (C) 2012 Sandro S. Andrade <sandroandrade@kde.org>
** Contact: http://www.qt-project.org/
**
** This file is part of the QtWrappedObjects module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** GNU Lesser General Public License Usage
@@ -42,7 +42,7 @@
#include <QtWrappedObjects/QWrappedObject>
-QT_BEGIN_NAMESPACE_QTWRAPPEDOBJECTS
+QT_BEGIN_NAMESPACE_QTWRAPPEDOBJECTSWIDGETS
QWrappedObjectModel::QWrappedObjectModel(QObject *parent) :
QAbstractItemModel(parent), _wrappedObject(0)
@@ -159,5 +159,5 @@ void QWrappedObjectModel::updateIndex(const QModelIndex &index)
#include "moc_qwrappedobjectmodel.cpp"
-QT_END_NAMESPACE_QTWRAPPEDOBJECTS
+QT_END_NAMESPACE_QTWRAPPEDOBJECTSWIDGETS
@@ -3,7 +3,7 @@
** Contact: http://www.qt-project.org/
**
-** This file is part of the QtWrappedObjects module of the Qt Toolkit.
+** This file is part of the QtWrappedObjectsWidgets module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
diff --git a/src/wrappedobjects/qwrappedobjectmodel.h b/src/wrappedobjectswidgets/qwrappedobjectmodel.h
index b9c4d2ec..bc19b271 100644
--- a/src/wrappedobjects/qwrappedobjectmodel.h
+++ b/src/wrappedobjectswidgets/qwrappedobjectmodel.h
@@ -3,7 +3,7 @@
** Copyright (C) 2012 Sandro S. Andrade <sandroandrade@kde.org>
** Contact: http://www.qt-project.org/
**
** This file is part of the QtWrappedObjects module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** GNU Lesser General Public License Usage
@@ -41,19 +41,24 @@
#ifndef QWRAPPEDOBJECTMODEL_H
#define QWRAPPEDOBJECTMODEL_H
+#include <QtWrappedObjectsWidgets/QtWrappedObjectsWidgetsGlobal>
#include <QtWrappedObjects/QtWrappedObjectsGlobal>
#include <QAbstractItemModel>
-QT_BEGIN_HEADER
-
QT_BEGIN_NAMESPACE_QTWRAPPEDOBJECTS
+class QWrappedObject;
+QT_END_NAMESPACE_QTWRAPPEDOBJECTS
-QT_MODULE(QtWrappedObjects)
+using QtWrappedObjects::QWrappedObject;
-class QWrappedObject;
+QT_BEGIN_HEADER
+
+QT_BEGIN_NAMESPACE_QTWRAPPEDOBJECTSWIDGETS
-class Q_WRAPPEDOBJECTS_EXPORT QWrappedObjectModel : public QAbstractItemModel
+QT_MODULE(QtWrappedObjectsWidgets)
+
+class Q_WRAPPEDOBJECTSWIDGETS_EXPORT QWrappedObjectModel : public QAbstractItemModel
{
Q_OBJECT
public:
@@ -78,7 +83,7 @@ private:
QWrappedObject *_wrappedObject;
};
-QT_END_NAMESPACE_QTWRAPPEDOBJECTS
+QT_END_NAMESPACE_QTWRAPPEDOBJECTSWIDGETS
QT_END_HEADER
@@ -3,7 +3,7 @@
** Contact: http://www.qt-project.org/
**
-** This file is part of the QtWrappedObjects module of the Qt Toolkit.
+** This file is part of the QtWrappedObjectsWidgets module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
diff --git a/src/wrappedobjects/qwrappedobjectpropertymodel.cpp b/src/wrappedobjectswidgets/qwrappedobjectpropertymodel.cpp
index 9417f596..3b554110 100644
--- a/src/wrappedobjects/qwrappedobjectpropertymodel.cpp
+++ b/src/wrappedobjectswidgets/qwrappedobjectpropertymodel.cpp
@@ -3,7 +3,7 @@
** Copyright (C) 2012 Sandro S. Andrade <sandroandrade@kde.org>
** Contact: http://www.qt-project.org/
**
** This file is part of the QtWrappedObjects module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** GNU Lesser General Public License Usage
@@ -48,7 +48,9 @@
#include <QtWrappedObjects/QMetaWrappedObject>
#include <QtWrappedObjects/QMetaPropertyInfo>
-QT_BEGIN_NAMESPACE_QTWRAPPEDOBJECTS
+using QtWrappedObjects::QMetaPropertyInfo;
+
+QT_BEGIN_NAMESPACE_QTWRAPPEDOBJECTSWIDGETS
QWrappedObjectPropertyModel::QWrappedObjectPropertyModel(QObject *parent) :
QAbstractItemModel(parent), _metaWrappedObject(0)
@@ -280,5 +282,5 @@ QWrappedObject *QWrappedObjectPropertyModel::wrappedObject() const
#include "moc_qwrappedobjectpropertymodel.cpp"
-QT_END_NAMESPACE_QTWRAPPEDOBJECTS
+QT_END_NAMESPACE_QTWRAPPEDOBJECTSWIDGETS
@@ -3,7 +3,7 @@
** Contact: http://www.qt-project.org/
**
-** This file is part of the QtWrappedObjects module of the Qt Toolkit.
+** This file is part of the QtWrappedObjectsWidgets module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
diff --git a/src/wrappedobjects/qwrappedobjectpropertymodel.h b/src/wrappedobjectswidgets/qwrappedobjectpropertymodel.h
index ef468b3c..a1b5f5cf 100644
--- a/src/wrappedobjects/qwrappedobjectpropertymodel.h
+++ b/src/wrappedobjectswidgets/qwrappedobjectpropertymodel.h
@@ -3,7 +3,7 @@
** Copyright (C) 2012 Sandro S. Andrade <sandroandrade@kde.org>
** Contact: http://www.qt-project.org/
**
** This file is part of the QtWrappedObjects module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** GNU Lesser General Public License Usage
@@ -41,20 +41,26 @@
#ifndef QWRAPPEDOBJECTPROPERTYMODEL_H
#define QWRAPPEDOBJECTPROPERTYMODEL_H
+#include <QtWrappedObjectsWidgets/QtWrappedObjectsWidgetsGlobal>
#include <QtWrappedObjects/QtWrappedObjectsGlobal>
#include <QAbstractItemModel>
-QT_BEGIN_HEADER
-
QT_BEGIN_NAMESPACE_QTWRAPPEDOBJECTS
-
-QT_MODULE(QtWrappedObjects)
-
class QWrappedObject;
class QMetaWrappedObject;
+QT_END_NAMESPACE_QTWRAPPEDOBJECTS
+
+using QtWrappedObjects::QWrappedObject;
+using QtWrappedObjects::QMetaWrappedObject;
-class Q_WRAPPEDOBJECTS_EXPORT QWrappedObjectPropertyModel : public QAbstractItemModel
+QT_BEGIN_HEADER
+
+QT_BEGIN_NAMESPACE_QTWRAPPEDOBJECTSWIDGETS
+
+QT_MODULE(QtWrappedObjectsWidgets)
+
+class Q_WRAPPEDOBJECTSWIDGETS_EXPORT QWrappedObjectPropertyModel : public QAbstractItemModel
{
Q_OBJECT
public:
@@ -84,7 +90,7 @@ private:
const QMetaWrappedObject *_metaWrappedObject;
};
-QT_END_NAMESPACE_QTWRAPPEDOBJECTS
+QT_END_NAMESPACE_QTWRAPPEDOBJECTSWIDGETS
QT_END_HEADER
@@ -3,7 +3,7 @@
** Contact: http://www.qt-project.org/
**
-** This file is part of the QtWrappedObjects module of the Qt Toolkit.
+** This file is part of the QtWrappedObjectsWidgets module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$